# Generated by Django 4.2.7 on 2023-10-31 23:48

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [
        ("wagtailimages", "0025_alter_image_file_alter_rendition_file"),
        ("cjkcms", "0016_layoutsettings_breadcrumb_icon_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="layoutsettings",
            name="default_seo_image",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="default_seo_image",
                to="wagtailimages.image",
                verbose_name="Default SEO Image",
            ),
        ),
    ]
