# Generated by Django 4.2.3 on 2023-08-04 20:23

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("cjkcms", "0012_remove_analyticssettings_ga_tracking_id_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="socialmediasettings",
            name="location",
            field=models.CharField(
                blank=True,
                choices=[
                    ("left", "left"),
                    ("right", "right"),
                    ("menu", "menu"),
                    ("none", "none"),
                ],
                default="none",
                max_length=50,
                verbose_name="Location of social media block",
            ),
        ),
    ]
